"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseISOString = exports.convertID = exports.createGetterAndSetter = exports.createOnlyGetter = void 0;

var createOnlyGetter = function createOnlyGetter(model, fieldName) {
  var fget = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : function () {
    return undefined;
  };
  Object.defineProperty(model, fieldName, {
    configurable: true,
    get: function get() {
      var value = fget(model._values[fieldName]);
      return value;
    },
    set: function set() {
      return false;
    }
  });
};

exports.createOnlyGetter = createOnlyGetter;

var createGetterAndSetter = function createGetterAndSetter(model, fieldName) {
  var fset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : function (value) {
    return value;
  };
  var fget = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : function (value) {
    return value;
  };

  var _checkHash = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;

  Object.defineProperty(model, fieldName, {
    configurable: true,
    get: function get() {
      if (_checkHash) {
        return {
          checkHash: function checkHash(value) {
            return _checkHash(value, model._values[fieldName]);
          }
        };
      } else {
        var value = fget(model._values[fieldName]);
        return value;
      }
    },
    set: function set(newValue) {
      var value = fset(newValue);
      model._values[fieldName] = value;
    }
  });
};

exports.createGetterAndSetter = createGetterAndSetter;

var convertID = function convertID(_ref) {
  var low = _ref.low,
      high = _ref.high;
  var res = high;

  for (var i = 0; i < 32; i++) {
    res *= 2;
  }

  return low + res;
};

exports.convertID = convertID;

var parseISOString = function parseISOString(s) {
  if (!s) return null;
  var b = s.split(/\D+/);
  return new Date(Date.UTC(b[0], --b[1], b[2], b[3], b[4], b[5], b[6]));
};

exports.parseISOString = parseISOString;